changeset 540:5c1a8d196182

THROW MORE DOTS
author Matti Hamalainen <ccr@tnsp.org>
date Tue, 24 Oct 2006 13:01:43 +0000
parents a82f43cea650
children 9b316c981d99
files ggrtf.tf
diffstat 1 files changed, 9 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/ggrtf.tf	Sat Oct 21 00:38:03 2006 +0000
+++ b/ggrtf.tf	Tue Oct 24 13:01:43 2006 +0000
@@ -1,8 +1,8 @@
 ;;
 ;; GgrTF v0.6.1.9-svn - TinyFugue script for BatMUD
 ;; (C) Copyright 2004-2006 Matti Hämäläinen (Ggr Pupunen)
 ;;
-/set ggrtf_ver=0.6.1.9-svn
+/set ggrtf_ver=0.6.1.10-svn
 ;;
 ;; This triggerset is Free Software distributed under
 ;; GNU General Public License version 2.
@@ -30,6 +30,9 @@
 	/prdefivar cnt_fucasts 0%;\
 	/prdefivar cnt_hastes 0%;\
 	/prdefivar cnt_ghastes 0%;\
+	/prdefivar cnt_qlips1 0%;\
+	/prdefivar cnt_qlips2 0%;\
+	/prdefivar cnt_qlips3 0%;\
 	/prdefivar cnt_trounds 0%;\
 	/prdefivar cnt_damcrits 0%;\
 	/prdefivar cnt_dcrit1 0%;\
@@ -1210,7 +1213,7 @@
 /prdefprot -i"epower"	-n"EPower"	-l"Earth Power" -u"You feel your strength changing. You flex you muscles experimentally." -d"The runic sigla \'% !^\' fade away.. leaving you feeling strange."
 /prdefprot -i"eskin"	-n"ESkin"	-l"Earth Skin" -M -s -u"You feel your skin harden." -d"Your skin feels softer."
 /prdefprot -i"eblood"	-n"EBlood"	-l"Earth Blood" -A" traces? icy blue runes on the ground with" -B" is surrounded by a sudden cloudburst" -u"An icy chill runs through your veins." -d"The runic sigla \'!( *)\' fade away.. leaving you feeling strange."
-/prdefprot -i"vmant"	-n"Vmant"	-l"Vine Mantle" -s -r -u"^Vines entangle your body\.$" -d"^The vines (around your body shrink|crumbles? to dust)\."
+/prdefprot -i"vmant"	-n"Vmant"	-l"Vine Mantle" -M -s -u"Vines entangle your body." -d"The vines around your body shrink."
 /prdefprot -i"regen"	-n"Rgn"		-l"Regeneration" -u"You feel your metabolism speed up." -d"You no longer have a active regeneration spell on you."
 
 ;; ---- Bard ----
@@ -1225,8 +1228,10 @@
 ;; ---- Conjurer::Basic Prots ----
 /prdefprot -i"sop"	-n"SoP"		-l"Shield of Protection" -A" \'nsiiznau\'$" -u"You feel a slight tingle." -d"You feel more vulnerable now."
 /prdefprot -i"bimage"	-n"BImg"	-l"Blurred Image" -A" \'ziiiuuuuns wiz\'$" -u"You feel a powerful aura." -d"You feel less invisible."
-/prdefprot -i"disp"	-n"Disp"	-l"Displacement" -A" \'diiiiuuunz aaanziz\'$" -u"You feel a powerful aura." -d"You feel much less invisible."
+/prdefprot -i"disp"	-n"Disp"	-l"Displacement" -A" \'diiiiuuunz aaanziz\'$" -r -u"^You feel a powerful aura\.$" -d"^You(r displacement spell wears off| feel much less invisible)\.$"
 /prdefprot -i"iwill"	-n"IWill"	-l"Iron Will" -u"You feel protected from being stunned." -d"You feel no longer protected from being stunned."
+/prdefprot -i"rentr"	-n"REntrop"	-l"Resist Entropy" -u"You feel your life force expanding." -d"You feel your hair is getting grayer."
+/prdefprot -i"rdisint"	-n"RDisInt"	-l"Resist Disintegrate" -u"You feel very firm." -d"You feel somewhat weaker."
 
 ;; ---- Conjurer::Minor Typeprots ----
 /prdefprot -i"c_phys"	-n"FAbs"	-l"Force Absorption"	-p -A"ztonez des deckers" -d"skin brown"
@@ -1,8 +1,8 @@
 ;;
-;; GgrTF v0.6.1.9-svn - TinyFugue script for BatMUD
+;; GgrTF v0.6.1.10-svn - TinyFugue script for BatMUD
 ;; (C) Copyright 2004-2006 Matti Hämäläinen (Ggr Pupunen)
 ;;